<?php

namespace Drupal\date_augmenter\DateAugmenter;

use Drupal\Core\Datetime\DrupalDateTime;
// use Drupal\date_augmenter\Datasource\DatasourceInterface;
// use Drupal\date_augmenter\Item\ItemInterface;
use Drupal\date_augmenter\Plugin\ConfigurablePluginInterface;

/**
 * Provides an interface for augmenter plugins.
 *
 * @see \Drupal\date_augmenter\Annotation\SearchApiDateAugmenter
 * @see \Drupal\date_augmenter\DateAugmenter\DateAugmenterPluginManager
 * @see \Drupal\date_augmenter\DateAugmenter\DateAugmenterPluginBase
 * @see plugin_api
 */
interface DateAugmenterInterface extends ConfigurablePluginInterface {

  /**
   * Returns the weight for a specific processing stage.
   *
   * @return int
   *   The default weight for the given stage.
   *
   * @see \Drupal\date_augmenter\DateAugmenter\DateAugmenterPluginManager::getProcessingStages()
   */
  public function getWeight();

  /**
   * Sets the weight for a specific processing stage.
   *
   * @param int $weight
   *   The weight for the given stage.
   *
   * @return $this
   *
   * @see \Drupal\date_augmenter\DateAugmenter\DateAugmenterPluginManager::getProcessingStages()
   */
  public function setWeight($weight);

  /**
   * Retrieves the properties this augmenter defines for the given datasource.
   *
   * Property names have to start with a letter or an underscore, followed by
   * any number of letters, numbers and underscores. To avoid collisions, it is
   * also recommended to prefix the property name with the identifier of the
   * module defining the augmenter.
   *
   * @param \Drupal\date_augmenter\Datasource\DatasourceInterface|null $datasource
   *   (optional) The datasource this set of properties belongs to. If NULL, the
   *   datasource-independent properties should be added (or modified).
   *
   * @return \Drupal\date_augmenter\DateAugmenter\DateAugmenterPropertyInterface[]
   *   An array of property definitions for that datasource, keyed by
   *   property names.
   */
  // public function getPropertyDefinitions(DatasourceInterface $datasource = NULL);

  /**
   * Adds the values of properties defined by this augmenter to the item.
   *
   * @param \Drupal\date_augmenter\Item\ItemInterface $item
   *   The item whose field values should be added.
   */
  // public function addFieldValues(ItemInterface $item);

  /**
   * Builds and returns a render array for the task.
   *
   * @param array $output
   *   The existing render array, to be augmented.
   * @param Drupal\Core\Datetime\DrupalDateTime $start
   *   The object which contains the start time.
   * @param Drupal\Core\Datetime\DrupalDateTime $end
   *   The optionalobject which contains the end time.
   * @param array $options
   *   An array of options to further guide output.
   *
   * @return array
   *   Returns a render array for the output of the task;
   */
  public function augmentOutput(array &$output, DrupalDateTime $start, DrupalDateTime $end = NULL, array $options = []);

}
